﻿namespace PureWeb
{
    class Configuration
    {
        private static readonly string ENV_STREAMER_PORT = "PUREWEB_STREAMER_PORT";
        private static readonly string ENV_SIDECAR_PORT = "PUREWEB_SIDECAR_PORT";
        private static readonly string ENV_STREAMING_AGENT_ADDRESS = "PUREWEB_STREAMING_AGENT_ADDRESS";

        private static readonly string DEFAULT_SIDECAR_PORT = "50051";
        private static readonly string DEFAULT_STREAMER_PORT = "9210";
        private static readonly string DEFAULT_STREAMING_AGENT_ADDRESS = "localhost";

        public string StreamingAgentAddress { get; private set; }
        public string StreamerPort { get; private set; }
        public string SidecarPort { get; private set; }

        public string StreamerUrl
        {
            get
            {
                return "ws://" + StreamingAgentAddress + ":" + StreamerPort;
            }
        }

        public string SidecarUrl
        {
            get
            {
                return StreamingAgentAddress + ":" + SidecarPort;
            }
        }

        public bool IsSidecarEnabled
        {
            get
            {
                return !string.IsNullOrEmpty(SidecarPort);
            }
        }

        public Configuration()
        {
            StreamingAgentAddress = GetEnvironmentVariable(ENV_STREAMING_AGENT_ADDRESS, DEFAULT_STREAMING_AGENT_ADDRESS);
            StreamerPort = GetEnvironmentVariable(ENV_STREAMER_PORT, DEFAULT_STREAMER_PORT);
            SidecarPort = GetEnvironmentVariable(ENV_SIDECAR_PORT, DEFAULT_SIDECAR_PORT);
        }

        private string GetEnvironmentVariable(string variableName, string defaultValue)
        {
            string variable = System.Environment.GetEnvironmentVariable(variableName);

            if (string.IsNullOrEmpty(variable))
            {
                return defaultValue;
            }
            else
            {
                return variable;
            }
        }
    }
}
