﻿using UnityEngine;
using System.Text;
using System;
using Unity.WebRTC;

namespace PureWeb
{
    #region Supported messages
    [Serializable]
    public class PlatformMessage
    {
        public int playerId;
        public string type;
    }

    [Serializable]
    public class PlatformSessionDescription : PlatformMessage
    {
        public string sdp;
    }

    [Serializable]
    public class PeerConnectionOptions
    {
        public RTCIceServer[] iceServers;
        public int iceCandidatePoolSize;
        public string iceTransportPolicy;
    }

    [Serializable]
    public class PlatformClientConfiguration : PlatformMessage
    {
        public PeerConnectionOptions peerConnectionOptions;
    }

    [Serializable]
    public class PlatformIceCandidateDescription : PlatformMessage
    {
        public PlatformIceCandidate candidate;
    }

    [Serializable]
    public class PlatformIceCandidate
    {
        public string candidate;
        public string sdpMid;
        public int sdpMLineIndex;
    }

    public static class PlatformRequestTypes
    {
        public const string RequestProcessInfo = "RequestProcessInfo";
        public const string RequestShutdown = "RequestShutdown";
    }

    public class PlatformRequest
    {
        public string type;
    }

    public class ProcessInfo
    {
        public int processId;
        public string appName;
        public string appId;
        public string schedulerId;
        public string serviceManagerId;
    }

    #endregion

    public static class PlatformMessaging
    {
        public static byte[] Serialize<T>(T source)
        {
            var json = JsonUtility.ToJson(source);
            var jsonBytes = Encoding.Unicode.GetBytes(json);
            var buffer = new byte[jsonBytes.Length + 1];
            buffer[0] = 1; // static response type 
            Array.Copy(jsonBytes, 0, buffer, 1, jsonBytes.Length);

            return buffer;
        }

        public static T Deserialize<T>(byte[] message)
        {
            var json = Encoding.Unicode.GetString(message, 0, message.Length);
            return JsonUtility.FromJson<T>(json);
        }
    }
}
