using UnityEngine.InputSystem;
using System.Collections.Generic;
using System.Linq;
using UnityEngine.InputSystem.Users;

namespace PureWeb
{
    public static class PureWebInputAdapterFactory
    {
        private static readonly Dictionary<PureWebInputAdapter, uint> s_mapRemoteInputAndInputUserId;
        private static readonly List<PureWebInputAdapter> s_listRemoteInput;
        private static readonly InputUser[] s_listUser;

        static PureWebInputAdapterFactory()
        {
            s_mapRemoteInputAndInputUserId = new Dictionary<PureWebInputAdapter, uint>();
            s_listRemoteInput = new List<PureWebInputAdapter>();
        }

        public static void Dispose()
        {
            s_mapRemoteInputAndInputUserId.Clear();
            s_listRemoteInput.Clear();
        }

        public static IReadOnlyList<PureWebInputAdapter> All()
        {
            return s_listRemoteInput;
        }

        public static PureWebInputAdapter Create()
        {
            InputUser user = InputUser.CreateUserWithoutPairedDevices();
            user = InputUser.PerformPairingWithDevice(InputSystem.AddDevice<Mouse>(), user);
            user = InputUser.PerformPairingWithDevice(InputSystem.AddDevice<Keyboard>(), user);
            user = InputUser.PerformPairingWithDevice(InputSystem.AddDevice<Gamepad>(), user);
            user = InputUser.PerformPairingWithDevice(InputSystem.AddDevice<Touchscreen>(), user);
            PureWebInputAdapter remoteInput = new PureWebInputAdapter(ref user);

            remoteInput.RemoteMouse.MakeCurrent();
            remoteInput.RemoteKeyboard.MakeCurrent();
            remoteInput.RemoteTouchscreen.MakeCurrent();
            remoteInput.RemoteGamepad.MakeCurrent();

            s_mapRemoteInputAndInputUserId.Add(remoteInput, user.id);
            s_listRemoteInput.Add(remoteInput);

            return remoteInput;
        }

        public static void Destroy(PureWebInputAdapter remoteInput)
        {
            uint userId = s_mapRemoteInputAndInputUserId[remoteInput];
            InputUser user = InputUser.all.First(_user => _user.id == userId);
            var arrayDeviceId = user.pairedDevices.Select(device => device.deviceId).ToArray();
            user.UnpairDevicesAndRemoveUser();
            foreach (var deviceId in arrayDeviceId)
            {
                InputSystem.RemoveDevice(InputSystem.GetDeviceById(deviceId));
            }
            s_mapRemoteInputAndInputUserId.Remove(remoteInput);
            s_listRemoteInput.Remove(remoteInput);
        }
    }
}
