﻿using UnityEngine;
using UnityEngine.InputSystem;

public class SimpleCameraController : MonoBehaviour
{
    [SerializeField] private float mousesensitivity = 3f;

    private Transform playerBody;
    private float xRotation;

    void Awake()
    {
        // Assign the player transform to playerBody
        playerBody = transform.parent;
    }

    void FixedUpdate()
    {
        // Get the current mouse controls
        var controls = Mouse.current;

        // Check that the controls are initalized
        if (controls == null)
        {
            return;
        }

        // Check that the right mouse button is held
        // Lock the controls and allow rotation if the right mouse button is held
        if (!controls.rightButton.isPressed)
        {
            Cursor.lockState = CursorLockMode.None;
            return;
        }
        else
        {
            Cursor.lockState = CursorLockMode.Locked;
        }

        // Get the mouse delta
        var look = controls.delta;
        var mouseX = look.x.ReadValue() * mousesensitivity * Time.deltaTime;
        var mouseY = look.y.ReadValue() * mousesensitivity * Time.deltaTime;

        // Determine the x rotation for the camera
        xRotation -= mouseY;
        xRotation = Mathf.Clamp(xRotation, -25f, 25f);

        // Rotate the camera and player
        transform.localRotation = Quaternion.Euler(xRotation, 0f, 0f);
        playerBody.Rotate(Vector3.up * mouseX);
    }
}